@@ -62,6 +62,16 @@ impl StivaleHeader {
         }
     }
 
+    /// Returns the stack pointer placed in this header.
+    pub fn get_stack(&self) -> *const u8 {
+        self.stack
+    }
+
+    /// Returns the flags stored in this header.
+    pub fn get_flags(&self) -> u64 {
+        self.flags
+    }
+
     pub const fn entry_point(mut self, func: extern "C" fn(&'static StivaleStruct) -> !) -> Self {
         self.entry_point = StivaleHeaderEntryPoint { func };
         self
@@ -141,7 +151,7 @@ make_header_tag!(
 make_header_tag!(
     /// If this tag is present the bootloader is instructed to unmap the first page of the virtual address
     /// space before passing control to the kernel, for architectures that support paging.
-    struct StivaleUnmapNullHeadertag: 0x92919432b16fe7e7;
+    struct StivaleUnmapNullHeaderTag: 0x92919432b16fe7e7;
 );
 
 unsafe impl Send for StivaleHeader {}
